summaryrefslogtreecommitdiffstats
path: root/printing/image.h
diff options
context:
space:
mode:
Diffstat (limited to 'printing/image.h')
-rw-r--r--printing/image.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/printing/image.h b/printing/image.h
index ed2820b..5f4746d 100644
--- a/printing/image.h
+++ b/printing/image.h
@@ -9,21 +9,22 @@
#include <vector>
#include "base/basictypes.h"
-#include "base/file_path.h"
#include "base/logging.h"
#include "gfx/size.h"
#include "printing/native_metafile.h"
+class FilePath;
+
namespace printing {
// Lightweight raw-bitmap management. The image, once initialized, is immutable.
// The main purpose is testing image contents.
class Image {
public:
// Creates the image from the given filename on disk. Uses extension to
// defer file type. PNG and EMF (on Windows) currently supported.
// If image loading fails size().IsEmpty() will be true.
- explicit Image(const std::wstring& filename);
+ explicit Image(const FilePath& path);
// Creates the image from the metafile. Deduces bounds based on bounds in
// metafile. If loading fails size().IsEmpty() will be true.
@@ -9,21 +9,22 @@
class Image {
public:
- // Creates the image from the given filename on disk. Uses extension to
+ // Creates the image from the given file on disk. Uses extension to
// defer file type. PNG and EMF (on Windows) currently supported.
// If image loading fails size().IsEmpty() will be true.